.. Gqrx Client documentation master file, created by
   sphinx-quickstart on Sun Aug 27 11:30:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Gqrx Client's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`



Autodoc
=======

.. automodule:: gqrx_client
   :members:


.. autoclass:: GqrxClient
   :members:

   .. automethod:: __init__


.. autoclass:: DemodulatorMode
   :members:


.. autoclass:: GqrxClientError
   :members:


.. autoclass:: CommandFailedGqrxClientError
   :members: